/* 
 * File:   IO_Functions.h
 * Author: rmcnamee
 *
 * Created on December 8, 2017, 8:08 AM
 */

#ifndef IO_FUNCTIONS_H
#define	IO_FUNCTIONS_H

#include "main.h"

/**
  @Summary
    Sets the CTS low to allow sending all sent data to the host

  @Description
    This routine tells the MCP2200 chip to send all data in its buffer to
 * the host. There is a maximum of 64 bits in its buffer, so this command
 * should be toggled before reaching that limit  

  @Param
    None
*/
void SetCtsLowForSerialSend(void);

/**
  @Summary
    Sets the CTS high after calling SetCtsLowForSerialSend()

  @Description
    This routine sets the CTS line high, not letting the MCP2200 chip
 * send any data back to the host

  @Param
    None
*/
void SetCtsHighForSerialSendComplete(void);

/**
  @Summary
    Enables the Flash memory chip select for SPI

  @Description
    Enables the Flash memory chip select for SPI (By setting the CS line
 * low)

  @Param
    None
*/
void EnableFlashChipSelect(void);

/**
  @Summary
    Disables the Flash memory chip select for SPI

  @Description
    Disables the Flash memory chip select for SPI (By setting the CS line
 * high)

  @Param
    None
*/
void DisableFlashChipSelect(void);

/**
  @Summary
    Disables the Flash memory chip write protection

  @Description
    Disables the Flash memory chip write protection

  @Param
    None
*/
void DisableFlashWriteProtect(void);

/**
  @Summary
    Enables the Flash memory chip write protection

  @Description
    Enables the Flash memory chip write protection

  @Param
    None
*/
void EnableFlashWriteProtect(void);

/**
  @Summary
    Sets up the default values

  @Description
    Sets up the default values

  @Param
    None
*/
void SetupIo(void);

/**
   @Param
    none
   @Returns
    none
   @Description
    Enables power to the switches
   @Example
    EnablePowerToSwitches();
 */
void EnablePowerToSwitches(void);

/**
   @Param
    none
   @Returns
    none
   @Description
    Disables power to the switches
   @Example
    DisablePowerToSwitches();
 */
void DisablePowerToSwitches(void);

/**
   @Param
    none
   @Returns
    none
   @Description
    Enables switch 1 SPI chip select
   @Example
    EnableSwitch1ChipSelect();
 */
void EnableSwitch1ChipSelect(void);

/**
   @Param
    none
   @Returns
    none
   @Description
    Disables switch 1 SPI chip select
   @Example
    DisableSwitch1ChipSelect();
 */
void DisableSwitch1ChipSelect(void);

/**
   @Param
    none
   @Returns
    none
   @Description
    Enables switch 2 SPI chip select
   @Example
    EnableSwitch2ChipSelect();
 */
void EnableSwitch2ChipSelect(void);

/**
   @Param
    none
   @Returns
    none
   @Description
    Disables switch 2 SPI chip select
   @Example
    DisableSwitch2ChipSelect();
 */
void DisableSwitch2ChipSelect(void);

/**
   @Param
    none
   @Returns
    True if the switch has been pressed, false otherwise
   @Description
    Checks if switch 1 has been pressed
   @Example
    CheckIfSwitch1Pressed();
 */
bool CheckIfSwitch1Pressed(void);

/**
   @Param
    none
   @Returns
    True if the switch has been pressed, false otherwise
   @Description
    Checks if switch 2 has been pressed
   @Example
    CheckIfSwitch2Pressed();
 */
bool CheckIfSwitch2Pressed(void);

#endif	/* IO_FUNCTIONS_H */

